sprunge.py
==========

A small python script to make uploading files to http://sprunge.us easier.

Dependencies
============

requests_ by Kenneth Reitz

.. _requests: https://github.com/kennethreitz/requests


Usage
=====

::

    $ sprunge.py -f file.txt
    $ <command> | sprunge.py
    $ sprunge.py < file.txt
    $ sprunge.py <( <command> )


Install
=======

::

    pip install sprunge.py

Author
======

* Ian Cordasco
